@@ -1,6 +1,7 @@
 # coding=utf-8
 
 from functools import wraps
+from contextlib import contextmanager
 
 from django.core.signals import request_finished
 
@@ -13,3 +14,8 @@ def close_connection(f):
         finally:
             request_finished.send(sender='greenlet')
     return wrapper
+
+
+@contextmanager
+def nullcontext(enter_result=None):
+    yield enter_result
